@@ -1,5 +1,5 @@
 /* libmondo-devices.c                 Subroutines for handling devices
-   $Id: libmondo-devices.c 1316 2007-04-16 14:50:28Z bruno $
+   $Id: libmondo-devices.c 1522 2007-06-29 10:37:50Z bruno $
 .
 
 
@@ -251,7 +251,7 @@
 #endif
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-devices.c 1316 2007-04-16 14:50:28Z bruno $";
+//static char cvsid[] = "$Id: libmondo-devices.c 1522 2007-06-29 10:37:50Z bruno $";
 
 extern int g_current_media_number;
 extern double g_kernel_version;
@@ -1882,7 +1882,7 @@ int interactively_obtain_media_parameters_from_user(struct s_bkpinfo
 			if (bkpinfo->backup_media_type == dvd) {
 				find_dvd_device(bkpinfo->media_device, FALSE);
 				strcpy(tmp, "1");
-				sprintf(sz_size, "%d", DEFAULT_DVD_DISK_SIZE);	// 4.7 salesman's GB = 4.482 real GB = 4582 MB
+				sprintf(sz_size, "%d", DEFAULT_DVD_DISK_SIZE);	// 4.7 salesman's GB = 4.482 real GB = 4482 MB
 				log_msg(1, "Setting to DVD defaults");
 			} else {
 				strcpy(bkpinfo->media_device, VANILLA_SCSI_CDROM);
@@ -2189,7 +2189,7 @@ int interactively_obtain_media_parameters_from_user(struct s_bkpinfo
 		if (!bkpinfo->disaster_recovery) {
 			if (!popup_and_get_string
 				("Storage dir.",
-				 "Please enter the full path that contains your ISO images.  Example: /mnt/raid0_0",
+				 "Please enter the full path name to the directory for your ISO images.  Example: /mnt/raid0_0",
 				 bkpinfo->isodir, MAX_STR_LEN / 4)) {
 				log_to_screen("User has chosen not to backup the PC");
 				finish(1);
@@ -2379,6 +2379,7 @@ int interactively_obtain_media_parameters_from_user(struct s_bkpinfo
 	log_it("exclude_paths = '%s'", bkpinfo->exclude_paths);
 	log_it("scratchdir = '%s'", bkpinfo->scratchdir);
 	log_it("tmpdir = '%s'", bkpinfo->tmpdir);
+	log_it("image_devs = '%s'", bkpinfo->image_devs);
 	log_it("boot_device = '%s' (loader=%c)", bkpinfo->boot_device,
 		   bkpinfo->boot_loader);
 	if (bkpinfo->media_size[0] < 0) {
@@ -2419,10 +2420,10 @@ char *list_of_NFS_devices_and_mounts(void)
 	malloc_string(exclude_these_directories);
 	strcpy(exclude_these_directories,
 		   call_program_and_get_last_line_of_output
-		   ("mount -t coda,ncpfs,nfs,smbfs,cifs,afs,mvfs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("mount -t coda,ncpfs,nfs,smbfs,cifs,afs,ocfs,ocfs2,mvfs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	strcpy(exclude_these_devices,
 		   call_program_and_get_last_line_of_output
-		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs|mvfs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs|afs|ocfs|ocfs2|mvfs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	sprintf(result_sz, "%s %s", exclude_these_directories,
 			exclude_these_devices);
 	paranoid_free(exclude_these_devices);
@@ -2449,10 +2450,10 @@ char *list_of_NFS_mounts_only(void)
 	malloc_string(exclude_these_directories);
 	strcpy(exclude_these_directories,
 		   call_program_and_get_last_line_of_output
-		   ("mount -t coda,ncpfs,nfs,smbfs,cifs,afs,mvfs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("mount -t coda,ncpfs,nfs,smbfs,cifs,afs,ocfs,ocfs2,mvfs | tr -s '\t' ' ' | cut -d' ' -f3 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	strcpy(exclude_these_devices,
 		   call_program_and_get_last_line_of_output
-		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs|mvfs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
+		   ("tr -s '\t' ' ' < /etc/fstab | grep -E '( (coda|ncpfs|nfs|smbfs|cifs|afs|ocfs|ocfs2|mvfs) )' | cut -d' ' -f1 | tr -s '\n' ' ' | awk '{print $0;}'"));
 	sprintf(result_sz, "%s", exclude_these_directories);
 	paranoid_free(exclude_these_devices);
 	paranoid_free(exclude_these_directories);
@@ -2511,11 +2512,11 @@ void sensibly_set_tmpdir_and_scratchdir(struct s_bkpinfo *bkpinfo)
 #ifdef __FreeBSD__
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
-		   ("df -m -P -t nonfs,msdosfs,ntfs,smbfs,smb,cifs,afs,mvfs | tr -s '\t' ' ' | grep -vE \"none|Filesystem\" | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
+		   ("df -m -P -t nonfs,msdosfs,ntfs,smbfs,smb,cifs,afs,ocfs,ocfs2,mvfs | tr -s '\t' ' ' | grep -vE \"none|Filesystem\" | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
 #else
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
-		   ("df -m -P -x nfs -x vfat -x ntfs -x smbfs -x smb -x cifs -x afs -x mvfs | sed 's/                  /devdev/' | tr -s '\t' ' ' | grep -vE \"none|Filesystem|/dev/shm\" | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
+		   ("df -m -P -x nfs -x vfat -x ntfs -x smbfs -x smb -x cifs -x afs -x ocfs -x ocfs2 -x mvfs | sed 's/                  /devdev/' | tr -s '\t' ' ' | grep -vE \"none|Filesystem|/dev/shm\" | awk '{printf \"%s %s\\n\", $4, $6;}' | sort -n | tail -n1 | awk '{print $NF;}'"));
 #endif
 
 	if (tmp[0] != '/') {
@@ -2789,8 +2790,6 @@ char which_boot_loader(char *which_device)
 		log_OS_error("Cannot pclose pdrives");
 	}
 	log_it("%d grubs and %d lilos\n", count_grubs, count_lilos);
-	paranoid_free(list_drives_cmd);
-	paranoid_free(current_drive);
 	if (count_grubs && !count_lilos) {
 		return ('G');
 	} else if (count_lilos && !count_grubs) {
@@ -2799,8 +2798,49 @@ char which_boot_loader(char *which_device)
 		log_it("I'll bet you used to use LILO but switched to GRUB...");
 		return ('G');
 	} else {
-		log_it("Unknown boot loader");
-		return ('U');
+		// We need to look on each partition then
+		sprintf(list_drives_cmd,
+			"parted2fdisk -l 2>/dev/null | grep -E \"^/dev/\" | tr -s ':' ' ' | tr -s ' ' '\n' | grep /dev/");
+		log_it("list_drives_cmd = %s", list_drives_cmd);
+
+		if (!(pdrives = popen(list_drives_cmd, "r"))) {
+			log_OS_error("Unable to open list of drives");
+			paranoid_free(list_drives_cmd);
+			paranoid_free(current_drive);
+			return ('\0');
+		}
+		for (fgets(current_drive, MAX_STR_LEN, pdrives); !feof(pdrives);
+		 	fgets(current_drive, MAX_STR_LEN, pdrives)) {
+			strip_spaces(current_drive);
+			log_it("looking at partition %s's BR", current_drive);
+			if (does_string_exist_in_boot_block(current_drive, "GRUB")) {
+				count_grubs++;
+				strcpy(which_device, current_drive);
+				break;
+			}
+			if (does_string_exist_in_boot_block(current_drive, "LILO")) {
+				count_lilos++;
+				strcpy(which_device, current_drive);
+				break;
+			}
+		}
+		if (pclose(pdrives)) {
+			log_OS_error("Cannot pclose pdrives");
+		}
+		log_it("%d grubs and %d lilos\n", count_grubs, count_lilos);
+		paranoid_free(list_drives_cmd);
+		paranoid_free(current_drive);
+		if (count_grubs && !count_lilos) {
+			return ('G');
+		} else if (count_lilos && !count_grubs) {
+			return ('L');
+		} else if (count_grubs == 1 && count_lilos == 1) {
+			log_it("I'll bet you used to use LILO but switched to GRUB...");
+			return ('G');
+		} else {
+			log_it("Unknown boot loader");
+			return ('U');
+		}
 	}
 }
 #endif
