@@ -1,5 +1,5 @@
 /* libmondo-filelist.c
-   $Id: libmondo-filelist.c 1316 2007-04-16 14:50:28Z bruno $
+   $Id: libmondo-filelist.c 1485 2007-06-05 21:45:29Z bruno $
 
 - for subroutines which manipulate the filelist
 
@@ -144,7 +144,7 @@ int mondo_makefilelist(char *logfile, char *tmpdir, char *scratchdir,
 
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-filelist.c 1316 2007-04-16 14:50:28Z bruno $";
+//static char cvsid[] = "$Id: libmondo-filelist.c 1485 2007-06-05 21:45:29Z bruno $";
 
 /**
  * Number of lines in the filelist last loaded.
@@ -264,13 +264,14 @@ int sort_file(char *orig_fname)
 	char *command;
 	int retval = 0;
 
-	log_msg(1, "Sorting file %s", orig_fname);
+	log_msg(5, "Sorting file %s", orig_fname);
 	malloc_string(tmp_fname);
 	malloc_string(command);
 	sprintf(tmp_fname, "/tmp/sort.%d.%d.%d", (int) (random() % 32768),
 			(int) (random() % 32768), (int) (random() % 32768));
 
 	if (!does_file_exist(orig_fname)) {
+		log_msg(2, "file %s empty", orig_fname);
 		return (0);
 	}							// no sense in trying to sort an empty file
 
@@ -280,20 +281,20 @@ int sort_file(char *orig_fname)
 	if (retval) {
 		log_msg(2, "Failed to sort %s - oh dear", orig_fname);
 	} else {
-		log_msg(2, "Sorted %s --> %s OK. Copying it back to %s now",
+		log_msg(5, "Sorted %s --> %s OK. Copying it back to %s now",
 				orig_fname, tmp_fname, orig_fname);
 		sprintf(command, "mv -f %s %s", tmp_fname, orig_fname);
-		retval += run_program_and_log_output(command, 2);
+		retval += run_program_and_log_output(command, 5);
 		if (retval) {
 			log_msg(2, "Failed to copy %s back to %s - oh dear", tmp_fname,
 					orig_fname);
 		} else {
-			log_msg(2, "%s was sorted OK.", orig_fname);
+			log_msg(5, "%s was sorted OK.", orig_fname);
 		}
 	}
 	paranoid_free(tmp_fname);
 	paranoid_free(command);
-	log_msg(1, "Finished sorting file %s", orig_fname);
+	log_msg(5, "Finished sorting file %s", orig_fname);
 	return (retval);
 }
 
@@ -1749,7 +1750,7 @@ int mondo_makefilelist(char *logfile, char *tmpdir, char *scratchdir,
 		log_msg(1, "Calculating filelist");
 		sprintf(exclude_paths, " %s %s %s %s %s %s . .. \
 " MNT_CDROM " " MNT_FLOPPY " /media \
-/proc /sys /root/images/mondo /root/images/mindi ", excp, call_program_and_get_last_line_of_output("locate /win386.swp 2> /dev/null"), call_program_and_get_last_line_of_output("locate /hiberfil.sys 2> /dev/null"), call_program_and_get_last_line_of_output("locate /pagefile.sys 2> /dev/null"), (tmpdir[0] == '/' && tmpdir[1] == '/') ? (tmpdir + 1) : tmpdir, (scratchdir[0] == '/' && scratchdir[1] == '/') ? (scratchdir + 1) : scratchdir);
+/proc /sys /root/images/mondo " MINDI_CACHE, excp, call_program_and_get_last_line_of_output("locate /win386.swp 2> /dev/null"), call_program_and_get_last_line_of_output("locate /hiberfil.sys 2> /dev/null"), call_program_and_get_last_line_of_output("locate /pagefile.sys 2> /dev/null"), (tmpdir[0] == '/' && tmpdir[1] == '/') ? (tmpdir + 1) : tmpdir, (scratchdir[0] == '/' && scratchdir[1] == '/') ? (scratchdir + 1) : scratchdir);
 
 		log_msg(2, "Excluding paths = '%s'", exclude_paths);
 		log_msg(2,
