@@ -1,5 +1,5 @@
 /* libmondo-fork.c
-   $Id: libmondo-fork.c 1999 2008-07-10 16:37:04Z bruno $
+   $Id: libmondo-fork.c 1316 2007-04-16 14:50:28Z bruno $
 
 - subroutines for handling forking/pthreads/etc.
 
@@ -111,14 +111,12 @@
 #include "lib-common-externs.h"
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-fork.c 1999 2008-07-10 16:37:04Z bruno $";
+//static char cvsid[] = "$Id: libmondo-fork.c 1316 2007-04-16 14:50:28Z bruno $";
 
+extern char *g_tmpfs_mountpt;
 extern t_bkptype g_backup_media_type;
 extern bool g_text_mode;
 extern char *MONDO_LOGFILE;
-
-/* Reference to global bkpinfo */
-extern struct s_bkpinfo *bkpinfo;
 pid_t g_buffer_pid = 0;
 
 
@@ -186,7 +184,8 @@ char *call_program_and_get_last_line_of_output(char *call)
  * @bug @p logstub is unused.
  */
 int
-eval_call_to_make_ISO(char *basic_call, char *isofile,
+eval_call_to_make_ISO(struct s_bkpinfo *bkpinfo,
+					  char *basic_call, char *isofile,
 					  int cd_no, char *logstub, char *what_i_am_doing)
 {
 
@@ -286,47 +285,13 @@ eval_call_to_make_ISO(char *basic_call, char *isofile,
 	paranoid_free(incoming);
 	paranoid_free(old_stderr);
 	paranoid_free(cd_number_str);
-	return (retval);
-}
-
-
-/**
- * Call copy of data to create an USB image.
- * @param bkpinfo The backup information structure. Fields used:
- * - @c bkpinfo->backup_media_type
- * @return Exit code of @c copy (0 is success, anything else indicates failure).
- */
-int
-eval_call_to_make_USB(char *command, char *what_i_am_doing) {
-
-	/*@ int's  *** */
-	int retval = 0;
-
-
-/*@***********   End Variables ***************************************/
-
-	log_msg(3, "Starting");
-	assert(bkpinfo != NULL);
-
-	log_to_screen
-		("Please be patient. Do not be alarmed by on-screen inactivity.");
-	log_msg(4, "Calling open_evalcall_form() with what_i_am_doing='%s'",
-			what_i_am_doing);
-
-	if (!g_text_mode) {
-		newtSuspend();
-	}
-	log_msg(1, "command = '%s'", command);
-	if (!g_text_mode) {
-		retval = run_external_binary_with_percentage_indicator_NEW
-			(what_i_am_doing, command);
-	} else {
-		retval += system(command);
-	}
-	if (!g_text_mode) {
-		newtResume();
-	}
-
+/*
+  if (bkpinfo->backup_media_type == dvd && !bkpinfo->please_dont_eject_when_restoring)
+    {
+      log_msg(3, "Ejecting DVD device");
+      eject_device(bkpinfo->media_device);
+    }
+*/
 	return (retval);
 }
 
@@ -373,8 +338,9 @@ int run_program_and_log_output(char *program, int debug_level)
 		log_if_success = TRUE;
 		log_if_failure = TRUE;
 	}
-	sprintf(callstr, "%s > %s/mondo-run-prog-thing.tmp 2> %s/mondo-run-prog-thing.err",
-			 program, bkpinfo->tmpdir, bkpinfo->tmpdir);
+	sprintf(callstr,
+			"%s > /tmp/mondo-run-prog-thing.tmp 2> /tmp/mondo-run-prog-thing.err",
+			program);
 	while ((p = strchr(callstr, '\r'))) {
 		*p = ' ';
 	}
@@ -401,14 +367,15 @@ int run_program_and_log_output(char *program, int debug_level)
 		log_msg(0,
 				"--------------------------------start of output-----------------------------");
 	}
-	sprintf(callstr, "cat %s/mondo-run-prog-thing.err >> %s/mondo-run-prog-thing.tmp 2> /dev/null", bkpinfo->tmpdir, bkpinfo->tmpdir);
-	if (log_if_failure && system(callstr)) {
+	if (log_if_failure
+		&&
+		system
+		("cat /tmp/mondo-run-prog-thing.err >> /tmp/mondo-run-prog-thing.tmp 2> /dev/null"))
+	{
 		log_OS_error("Command failed");
 	}
-	sprintf(tmp, "%s/mondo-run-prog-thing.err", bkpinfo->tmpdir);
-	unlink(tmp);
-	sprintf(tmp, "%s/mondo-run-prog-thing.tmp", bkpinfo->tmpdir);
-	fin = fopen(tmp, "r");
+	unlink("/tmp/mondo-run-prog-thing.err");
+	fin = fopen("/tmp/mondo-run-prog-thing.tmp", "r");
 	if (fin) {
 		for (fgets(incoming, MAX_STR_LEN, fin); !feof(fin);
 			 fgets(incoming, MAX_STR_LEN, fin)) {
@@ -429,7 +396,7 @@ int run_program_and_log_output(char *program, int debug_level)
 		}
 		paranoid_fclose(fin);
 	}
-	unlink(tmp);
+	unlink("/tmp/mondo-run-prog-thing.tmp");
 	if ((res == 0 && log_if_success) || (res != 0 && log_if_failure)) {
 		log_msg(0,
 				"--------------------------------end of output------------------------------");
@@ -473,8 +440,8 @@ int run_program_and_log_to_screen(char *basic_call, char *what_i_am_doing)
 
 	assert_string_is_neither_NULL_nor_zerolength(basic_call);
 
-	sprintf(lockfile, "%s/mojo-jojo.bla.bla", bkpinfo->tmpdir);
-
+	sprintf(lockfile, "/tmp/mojo-jojo.blah.XXXXXX");
+	mkstemp(lockfile);
 	sprintf(command,
 			"echo hi > %s ; %s >> %s 2>> %s; res=$?; sleep 1; rm -f %s; exit $res",
 			lockfile, basic_call, MONDO_LOGFILE, MONDO_LOGFILE, lockfile);
@@ -546,7 +513,6 @@ int copy_from_src_to_dest(FILE * f_orig, FILE * f_archived, char direction)
 // if dir=='r' then copy from archived to orig
 	char *tmp;
 	char *buf;
-	char filestr[MAX_STR_LEN];
 	long int bytes_to_be_read, bytes_read_in, bytes_written_out =
 		0, bufcap, subsliceno = 0;
 	int retval = 0;
@@ -647,8 +613,7 @@ int copy_from_src_to_dest(FILE * f_orig, FILE * f_archived, char direction)
 			}
 			log_msg(5, "tmpB is %s", tmp);
 			if (!strstr(tmp, PIMP_END_SZ)) {
-				sprintf(filestr, "%s/out.leftover", bkpinfo->tmpdir);
-				ftmp = fopen(filestr, "w");
+				ftmp = fopen("/tmp/out.leftover", "w");
 				bytes_read_in = fread(tmp, 1, 64, fin);
 				log_msg(1, "bytes_read_in = %ld", bytes_read_in);
 //      if (bytes_read_in!=128+64) { fatal_error("Can't read the terminating block"); }
@@ -700,6 +665,77 @@ int feed_into_ntfsprog(char *input_device, char *output_fname)
 }
 
 
+
+
+
+int run_external_binary_with_percentage_indicator_OLD(char *tt, char *cmd)
+{
+
+	/*@ int *************************************************************** */
+	int res = 0;
+	int percentage = 0;
+	int maxpc = 0;
+	int pcno = 0;
+	int last_pcno = 0;
+
+	/*@ buffers *********************************************************** */
+	char *command;
+	char *tempfile;
+	char *title;
+	/*@ pointers ********************************************************** */
+	FILE *pin;
+
+	malloc_string(title);
+	malloc_string(command);
+	malloc_string(tempfile);
+	assert_string_is_neither_NULL_nor_zerolength(cmd);
+	assert_string_is_neither_NULL_nor_zerolength(title);
+
+	strcpy(title, tt);
+	strcpy(tempfile,
+		   call_program_and_get_last_line_of_output
+		   ("mktemp -q /tmp/mondo.XXXXXXXX"));
+	sprintf(command, "%s >> %s 2>> %s; rm -f %s", cmd, tempfile, tempfile,
+			tempfile);
+	log_msg(3, command);
+	open_evalcall_form(title);
+	if (!(pin = popen(command, "r"))) {
+		log_OS_error("fmt err");
+		return (1);
+	}
+	maxpc = 100;
+// OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD
+	for (sleep(1); does_file_exist(tempfile); sleep(1)) {
+		pcno = grab_percentage_from_last_line_of_file(MONDO_LOGFILE);
+		if (pcno < 0 || pcno > 100) {
+			log_msg(5, "Weird pc#");
+			continue;
+		}
+		percentage = pcno * 100 / maxpc;
+		if (pcno <= 5 && last_pcno > 40) {
+			close_evalcall_form();
+			strcpy(title, "Verifying...");
+			open_evalcall_form(title);
+		}
+		last_pcno = pcno;
+		update_evalcall_form(percentage);
+	}
+// OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD OLD
+	close_evalcall_form();
+	if (pclose(pin)) {
+		res++;
+		log_OS_error("Unable to pclose");
+	}
+	unlink(tempfile);
+	paranoid_free(command);
+	paranoid_free(tempfile);
+	paranoid_free(title);
+	return (res);
+}
+
+
+
+
 void *run_prog_in_bkgd_then_exit(void *info)
 {
 	char *sz_command;
