@@ -1,5 +1,5 @@
 /* libmondo-mountlist.c                            subroutines for handling mountlist
-   $Id: libmondo-mountlist.c 1303 2007-04-15 00:33:22Z bruno $
+   $Id: libmondo-mountlist.c 1439 2007-05-15 23:30:46Z bruno $
 
 
 
@@ -60,7 +60,7 @@
 #include "newt-specific-EXT.h"
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-mountlist.c 1303 2007-04-15 00:33:22Z bruno $";
+//static char cvsid[] = "$Id: libmondo-mountlist.c 1439 2007-05-15 23:30:46Z bruno $";
 
 /**
  * A global copy of @c bkpinfo, to aid in debugging. As the name implies, <em>don't use this</em>.
@@ -370,8 +370,6 @@ int evaluate_drive_within_mountlist(struct mountlist_itself *mountlist,
 				physical_drive_size - amount_allocated, drive);
 		log_it(tmp);
 		strcat(flaws_str, tmp);
-		/* BERLIOS: Flawed since rev 1 !! */
-		res++;
 	}
 	if (res) {
 		return (FALSE);
@@ -520,8 +518,6 @@ int evaluate_drive_within_mountlist(struct mountlist_itself *mountlist,
 				physical_drive_size - amount_allocated, drive);
 		log_it(tmp);
 		strcat(flaws_str, tmp);
-		/* BERLIOS: Flawed since rev 1 !! */
-		res++;
 	}
 
   endoffunc:
@@ -1068,7 +1064,7 @@ int save_mountlist_to_disk(struct mountlist_itself *mountlist, char *fname)
 	}
 	for (i = 0; i < mountlist->entries; i++) {
 		fprintf(fout,
-				"%-15s %-15s %-15s %-15lld %-15s\n",
+				"%-15s %-15s %-15s %-15lld %-15s %-15s\n",
 				mountlist->el[i].device, mountlist->el[i].mountpoint,
 				mountlist->el[i].format, mountlist->el[i].size,
 				mountlist->el[i].label, mountlist->el[i].uuid);
