@@ -1,4 +1,4 @@
-/* $Id: libmondo-string.c 1687 2007-10-20 12:47:12Z bruno $ */
+/* $Id: libmondo-string.c 1236 2007-03-11 23:23:16Z bruno $ */
 
 
 /**
@@ -15,14 +15,11 @@
 #include "libmondo-tools-EXT.h"
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-string.c 1687 2007-10-20 12:47:12Z bruno $";
+//static char cvsid[] = "$Id: libmondo-string.c 1236 2007-03-11 23:23:16Z bruno $";
 
 extern int g_current_media_number;
 extern long long g_tape_posK;
 
-/* Reference to global bkpinfo */
-extern struct s_bkpinfo *bkpinfo;
-
 
 /**
  * @addtogroup stringGroup
@@ -946,7 +943,7 @@ int severity_of_difference(char *fn, char *out_reason)
 	if (!strncmp(filename, "/home", 5)) {
 		sev = 2;
 		sprintf(reason,
-				"It's in your /home directory. Therefore, it is important.");
+				"It's in your /home partiton. Therefore, it is important.");
 	}
 	if (!strncmp(filename, "/usr/", 5)) {
 		sev = 3;
@@ -1064,7 +1061,7 @@ int compare_two_filelist_entries(void *va, void *vb)
  * @return The string indicating media fill.
  * @note The returned string points to static storage that will be overwritten with each call.
  */
-char *percent_media_full_comment()
+char *percent_media_full_comment(struct s_bkpinfo *bkpinfo)
 {
 	/*@ int *********************************************** */
 	int percentage;
@@ -1159,9 +1156,6 @@ char *media_descriptor_string(t_bkptype type_of_bkp)
 	case nfs:
 		strcpy(type_of_backup, "nfs");
 		break;
-    case usb:
-        strcpy(type_of_backup, "USB");
-        break;
 	default:
 		strcpy(type_of_backup, "ISO");
 	}
