@@ -1,5 +1,168 @@
-/*
-   $Id: libmondo-tools.c 2030 2008-10-02 23:50:44Z bruno $
+/* libmondo-tools.c                                  misc tools
+   $Id: libmondo-tools.c 1437 2007-05-10 21:41:11Z andree $
+.
+
+
+06/28
+- abort if RAID partitions found but /etc/raidtab not found
+
+06/25
+- don't insist on ms-sys; recommend it
+- don't fatal_error if can't open log file
+
+06/14
+- call mindi -V before calling mindi --makemountlist
+
+04/09
+- lots of malloc'd char*'s instead of char[]'s in post_param_config'n
+
+04/02
+- better sanity-checking, re: /etc/modules.conf
+
+02/15
+- abort if Windows dir but no ms-sys or parted
+
+02/08
+- missing ramdisk/initrd support is nonfatal now (but stupid)
+
+01/16
+- added g_kernel_version and get_kernel_version()
+
+01/08/2004
+- fixed /boot mounter thingy
+
+11/14/2003
+- if <50MB free in /root, softlink /root/images/mindi to
+  /home/root/images/mindi as a workaround
+
+10/23
+- streaming backups now generate 4MB sets; CDs, 8MB sets
+
+10/21
+- better at finding your /boot in order to mount it, if nec.
+- link /etc/modules.conf to /etc/conf.modules if former
+  is missing but latter is not
+- changed "/mnt/cdrom" to MNT_CDROM
+- changed "/mnt/floppy" to MNT_FLOPPY
+
+10/13
+- added stop_magicdev_if_necessary()
+- added restart_magicdev_if_necessary()
+
+10/02
+- don't eject if bkpinfo->please_dont_eject is TRUE
+
+09/28
+- fixed segfault in mount_..._necessary
+
+09/26
+- ask for cmp (or create workaround if possible)
+
+09/25
+- add DVD support
+
+09/24
+- don't overwrite existing media-dev value in bkpinfo IF it's
+  a tape device AND it's already populated by /dev/{something}
+  ...This helps w/ weird tape drives
+
+09/23
+- malloc/free global strings in new subroutines - malloc_libmondo_global_strings()
+  and free_libmondo_global_strings() - which are in libmondo-tools.c
+
+09/18
+- added stop_autofs_if_necessary() and restart_autofs_if_necessary()
+
+09/13
+- added log_debug_msg()
+- turned log_it() into a macro
+
+09/10
+- reduced PPCFG_RAMDISK to 150m (was 200m)
+- max set size is now 8MB (was 6)
+- added 'buffer' to requisite tools
+
+08/29
+- typical set size is now 5MB
+   
+07/22
+- increased PPCFG* to 200m
+
+05/07
+- changed grep -m1 to grep | head -n1 for Debian users
+- pre_param_...() also mkdir -p /mnt/cdrom, just in case
+
+05/05
+- cleaner logging of call to dd if=<tape> of=/dev/null
+- added Joshua Oreman's FreeBSD patches
+
+05/04
+- added Herman Kuster's multi-level bkp patch
+
+05/02
+- log_it() --- "Message repeated N times" (if it was)
+
+04/24
+- added lots of assert()'s and log_OS_error()'s
+- reset_bkpinfop() --- reset all media_size[] array
+- increased tmpfs ramdisk to size=100m
+
+04/22
+- post_param_configuration() --- store iso-dev and isodir
+
+04/05
+- re-enable tmpfs ramdisk/mountpt _but_ make sure size=80m
+- in post_param_configuration(), use cdrecord in preference
+  to dvdrecord now
+
+03/27
+- disabled tmpfs ramdisk/mountpt
+
+01/02/2003
+- bkpinfo->makefilelist = TRUE
+
+12/10/2002
+- added g_loglevel
+- fixed minor bug in clean_up_KDE_desktop_if_necessary()
+- log versions of newt, slang, ncurses
+- isodir defaults to / if disaster recovery
+
+11/28
+- unmount all CD devices at start
+- added clean_up_KDE_desktop_if_necessary()
+
+11/20
+- don't use lilo.conf.anaconda; abort instead
+- mount/unmount /boot partition for Gentoo 1.2 users
+
+11/13
+- call mindi --makemountlist as part of testing sanity of distro
+
+11/08
+- added a couple of chmod 700's (one for scratchdir, one for tmpdir)
+  to post_param_configuration()
+
+10/01 - 10/31
+- added checking of / and /root's free space to some_basic_sanity_checks()
+- moved some subroutines here from common/libmondo-archive
+
+09/01 - 09/30
+- don't write log_it()'s string to stdout, even if text mode
+- tell user the kernel is bad if it has no ramdisk support but allow
+  it if they want to use the failsafe kernel for booting
+- run_program_and_log_output() now takes boolean operator to specify
+  whether it will log its activities in the event of _success_
+- if mkfs.vfat not found but mkfs.msdos found then create a softlink
+  from the former to the latter
+
+08/01 - 08/31
+- if /etc/lilo.conf not found not /etc/lilo.conf.anaconda found
+  then create a softlink from the former to the latter, to work
+  around RH7.3's b0rken LILO support
+- handle unknown media size
+
+07/27
+- created
 */
 
 
@@ -16,27 +179,23 @@
 #include "libmondo-files-EXT.h"
 #include "libmondo-fork-EXT.h"
 #include "libmondo-raid-EXT.h"
-#include "libmondo-devices-EXT.h"
 #include <sys/socket.h>
 #include <netdb.h>
-#include <stdlib.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/utsname.h>
 
 /*@unused@*/
-//static char cvsid[] = "$Id: libmondo-tools.c 2030 2008-10-02 23:50:44Z bruno $";
+//static char cvsid[] = "$Id: libmondo-tools.c 1437 2007-05-10 21:41:11Z andree $";
 
 extern int g_tape_buffer_size_MB;
+extern char *g_erase_tmpdir_and_scratchdir;
 extern char *g_serial_string;
 extern bool g_text_mode;
 extern int g_currentY;
 extern int g_current_media_number;
 extern char *MONDO_LOGFILE;
 
-/* Reference to global bkpinfo */
-extern struct s_bkpinfo *bkpinfo;
-
 /**
  * @addtogroup globalGroup
  * @{
@@ -63,8 +222,8 @@ char *g_serial_string = NULL;
 
 /**
  * The location where tmpfs is mounted, or "" if it's not mounted.
-char *g_tmpfs_mountpt = NULL;
  */
+char *g_tmpfs_mountpt = NULL;
 char *g_magicdev_command = NULL;
 
 /**
@@ -82,17 +241,6 @@ extern t_bkptype g_backup_media_type;
 
 extern bool am_I_in_disaster_recovery_mode(void);
 
-/* Return a string containing the date */
-char *mr_date(void) {
-
-        time_t tcurr;
-
-        tcurr = time(NULL);
-        return(ctime(&tcurr));
-}
-
-/*-----------------------------------------------------------*/
-
 
 /**
  * @addtogroup utilityGroup
@@ -417,7 +565,7 @@ void log_trace(char *o)
  * @note Also creates directories that are specified in the @c bkpinfo structure but
  * do not exist.
  */
-int post_param_configuration()
+int post_param_configuration(struct s_bkpinfo *bkpinfo)
 {
 	char *extra_cdrom_params;
 	char *mondo_mkisofs_sz;
@@ -425,14 +573,12 @@ int post_param_configuration()
 	char *mtpt;
 	char *hostname, *ip_address;
 	int retval = 0;
+	long avm = 0;
 	char *colon;
 	char *cdr_exe;
 	char *tmp;
 	char call_before_iso_user[MAX_STR_LEN] = "\0";
-	/*
-	long avm = 0;
 	int rdsiz_MB;
-	*/
 	char *iso_dev;
 	char *iso_mnt;
 	char *iso_tmp;
@@ -466,20 +612,18 @@ int post_param_configuration()
 		}
 	}
 	make_hole_for_dir(bkpinfo->scratchdir);
+	make_hole_for_dir(bkpinfo->tmpdir);
 	if (bkpinfo->backup_media_type == iso)
 		make_hole_for_dir(bkpinfo->isodir);
 
 	run_program_and_log_output("uname -a", 5);
 	run_program_and_log_output("cat /etc/*-release", 5);
 	run_program_and_log_output("cat /etc/*issue*", 5);
-	/*
 	sprintf(g_tmpfs_mountpt, "%s/tmpfs", bkpinfo->tmpdir);
 	sprintf(command, "mkdir -p %s", g_tmpfs_mountpt);
 	paranoid_system(command);
 	rdsiz_MB = PPCFG_RAMDISK_SIZE + g_tape_buffer_size_MB;
-	*/
 #ifdef __FreeBSD__
-	/*
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
 		   ("vmstat | tail -1 | tr -s ' ' | cut -d' ' -f6"));
@@ -490,22 +634,18 @@ int post_param_configuration()
 	avm += atol(tmp);
 	sprintf(command, "mdmfs -s %d%c md9 %s", rdsiz_MB, 'm',
 			g_tmpfs_mountpt);
-			*/
 #else
-	/*
 	strcpy(tmp,
 		   call_program_and_get_last_line_of_output
 		   ("free | grep ':' | tr -s ' ' '\t' | cut -f2 | head -n1"));
 	avm += atol(tmp);
 	sprintf(command, "mount /dev/shm -t tmpfs %s -o size=%d%c",
 			g_tmpfs_mountpt, rdsiz_MB, 'm');
-			*/
 	run_program_and_log_output("cat /proc/cpuinfo", 5);
 	run_program_and_log_output
 		("rpm -q newt newt-devel slang slang-devel ncurses ncurses-devel gcc",
 		 5);
 #endif
-	/*
 	if (avm / 1024 > rdsiz_MB * 3) {
 		if (run_program_and_log_output(command, 5)) {
 			g_tmpfs_mountpt[0] = '\0';
@@ -517,7 +657,6 @@ int post_param_configuration()
 		g_tmpfs_mountpt[0] = '\0';
 		log_it("It doesn't seem you have enough swap to use tmpfs. Fine.");
 	}
-	*/
 
 	if (bkpinfo->use_lzo) {
 		strcpy(bkpinfo->zip_exe, "lzop");
@@ -625,17 +764,17 @@ int post_param_configuration()
 		if (bkpinfo->manual_cd_tray) {
 			if (bkpinfo->call_before_iso[0] == '\0') {
 			sprintf(bkpinfo->call_before_iso,
-						"%s -o %s/"MONDO_TMPISOS" . 2>> _ERR_",
+						"%s -o %s/temporary.iso . 2>> _ERR_",
 						mondo_mkisofs_sz, bkpinfo->tmpdir);
            		} else {
 				strncpy(call_before_iso_user, bkpinfo->call_before_iso, MAX_STR_LEN);
 				sprintf (bkpinfo->call_before_iso,
-                     				"( %s -o %s/"MONDO_TMPISOS" . 2>> _ERR_ ; %s )",
+                     				"( %s -o %s/temporary.iso . 2>> _ERR_ ; %s )",
 						mondo_mkisofs_sz, bkpinfo->tmpdir, call_before_iso_user);
 			}
 			log_it("bkpinfo->call_before_iso = %s", bkpinfo->call_before_iso);
 			sprintf(bkpinfo->call_make_iso,
-					"%s %s -v %s fs=4m dev=%s speed=%d %s/"MONDO_TMPISOS,
+					"%s %s -v %s fs=4m dev=%s speed=%d %s/temporary.iso",
 					cdr_exe, (bkpinfo->please_dont_eject) ? " " : "-eject",
 					extra_cdrom_params, bkpinfo->media_device,
 					bkpinfo->cdrw_speed, bkpinfo->tmpdir);
@@ -738,13 +877,17 @@ int post_param_configuration()
 				strcpy(bkpinfo->nfs_mount, ip_address);
 			}
 		}
-		store_nfs_config();
+		store_nfs_config(bkpinfo);
 	}
 
 	log_it("Finished processing incoming params");
 	if (retval) {
 		fprintf(stderr, "Type 'man mondoarchive' for help.\n");
 	}
+	sprintf(tmp, "%s", MONDO_TMPISOS);	/* added #define 22 apr 2002 */
+	if (does_file_exist(tmp)) {
+		unlink(tmp);
+	}
 	if (strlen(bkpinfo->tmpdir) < 2 || strlen(bkpinfo->scratchdir) < 2) {
 		log_it("tmpdir or scratchdir are blank/missing");
 		retval++;
@@ -754,6 +897,7 @@ int post_param_configuration()
 		strcpy(bkpinfo->include_paths, "/");
 	}
 	chmod(bkpinfo->scratchdir, 0700);
+	chmod(bkpinfo->tmpdir, 0700);
 	g_backup_media_type = bkpinfo->backup_media_type;
 	paranoid_free(mtpt);
 	paranoid_free(extra_cdrom_params);
@@ -779,15 +923,15 @@ int post_param_configuration()
  * @param bkpinfo The backup information structure. Will be initialized.
  * @return number of errors (0 for success)
  */
-int pre_param_configuration()
+int pre_param_configuration(struct s_bkpinfo *bkpinfo)
 {
 	int res = 0;
-	char *tmp = NULL;
 
 	make_hole_for_dir(MNT_CDROM);
 	assert(bkpinfo != NULL);
 	srandom((unsigned long) (time(NULL)));
 	insmod_crucial_modules();
+	reset_bkpinfo(bkpinfo);		// also sets defaults ('/'=backup path, 3=compression level)
 	if (bkpinfo->disaster_recovery) {
 		if (!does_nonMS_partition_exist()) {
 			fatal_error
@@ -796,9 +940,7 @@ int pre_param_configuration()
 	}
 
 	unlink(MONDO_TRACEFILE);
-	asprintf(&tmp,"rm -Rf %s/changed.files*",MONDO_CACHE);
-	run_program_and_log_output(tmp, FALSE);
-	paranoid_free(tmp);
+	run_program_and_log_output("rm -Rf /tmp/changed.files*", FALSE);
 	if (find_and_store_mondoarchives_home(g_mondo_home)) {
 		fprintf(stderr,
 				"Cannot find Mondo's homedir. I think you have >1 'mondo' directory on your hard disk. Please delete the superfluous 'mondo' directories and try again\n");
@@ -814,49 +956,22 @@ int pre_param_configuration()
 	return (res);
 }
 
-void setup_tmpdir(char *path) {
 
-	char *tmp = NULL;
-	char *p = NULL;
-
-	if ((bkpinfo->tmpdir != NULL) && (strstr(bkpinfo->tmpdir,"mondo.tmp.") != NULL)) {
-		/* purging a potential old tmpdir */
-		asprintf(&tmp,"rm -Rf %s",bkpinfo->tmpdir);
-		system(tmp);
-		paranoid_free(tmp);
-	}
-
-	if (path != NULL) {
-		asprintf(&tmp, "%s/mondo.tmp.XXXXXX", path);
-	} else if (getenv("TMPDIR")) {
-		asprintf(&tmp, "%s/mondo.tmp.XXXXXX", getenv("TMPDIR"));
-	} else if (getenv("TMP")) {
-		asprintf(&tmp, "%s/mondo.tmp.XXXXXX", getenv("TMP"));
-	} else {
-		asprintf(&tmp, "/tmp/mondo.tmp.XXXXXX");
-	}
-	p = mkdtemp(tmp);
-	if (p == NULL) {
-		log_it("Failed to create global tmp directory %s for Mondo.",tmp);
-		finish(-1);
-	}
-	strcpy(bkpinfo->tmpdir,p);
-	paranoid_free(tmp);
-}
 
 
 /**
  * Reset all fields of the backup information structure to a sensible default.
  * @param bkpinfo The @c bkpinfo to reset.
  */
-void reset_bkpinfo()
+void reset_bkpinfo(struct s_bkpinfo *bkpinfo)
 {
 	int i;
 
 	log_msg(1, "Hi");
 	assert(bkpinfo != NULL);
 	memset((void *) bkpinfo, 0, sizeof(struct s_bkpinfo));
-
+	bkpinfo->manual_cd_tray = FALSE;
+	bkpinfo->internal_tape_block_size = DEFAULT_INTERNAL_TAPE_BLOCK_SIZE;
 	bkpinfo->media_device[0] = '\0';
 	for (i = 0; i <= MAX_NOOF_MEDIA; i++) {
 		bkpinfo->media_size[i] = -1;
@@ -865,49 +980,45 @@ void reset_bkpinfo()
 	bkpinfo->boot_device[0] = '\0';
 	bkpinfo->zip_exe[0] = '\0';
 	bkpinfo->zip_suffix[0] = '\0';
-	bkpinfo->image_devs[0] = '\0';
-	bkpinfo->compression_level = 3;
+	bkpinfo->restore_path[0] = '\0';
 	bkpinfo->use_lzo = FALSE;
 	bkpinfo->use_gzip = FALSE;
 	bkpinfo->do_not_compress_these[0] = '\0';
 	bkpinfo->verify_data = FALSE;
 	bkpinfo->backup_data = FALSE;
 	bkpinfo->restore_data = FALSE;
-	bkpinfo->use_star = FALSE;
-	bkpinfo->internal_tape_block_size = DEFAULT_INTERNAL_TAPE_BLOCK_SIZE;
 	bkpinfo->disaster_recovery =
 		(am_I_in_disaster_recovery_mode()? TRUE : FALSE);
 	if (bkpinfo->disaster_recovery) {
 		strcpy(bkpinfo->isodir, "/");
 	} else {
-		strcpy(bkpinfo->isodir, "/var/cache/mondo");
+		strcpy(bkpinfo->isodir, "/root/images/mondo");
 	}
 	strcpy(bkpinfo->prefix, STD_PREFIX);
-	sensibly_set_tmpdir_and_scratchdir();
 
-	bkpinfo->optimal_set_size = 0;
-	strcpy(bkpinfo->include_paths, "/");
+	bkpinfo->scratchdir[0] = '\0';
 	bkpinfo->make_filelist = TRUE;	// unless -J supplied to mondoarchive
-	bkpinfo->include_paths[0] = '\0';
+	sprintf(bkpinfo->tmpdir, "/tmp/tmpfs/mondo.tmp.%d", (int) (random() % 32768));	// for mondorestore
+	bkpinfo->optimal_set_size = 0;
+	bkpinfo->backup_media_type = none;
+	strcpy(bkpinfo->include_paths, "/");
 	bkpinfo->exclude_paths[0] = '\0';
-	bkpinfo->restore_path[0] = '\0';
 	bkpinfo->call_before_iso[0] = '\0';
 	bkpinfo->call_make_iso[0] = '\0';
 	bkpinfo->call_burn_iso[0] = '\0';
 	bkpinfo->call_after_iso[0] = '\0';
+	bkpinfo->image_devs[0] = '\0';
+	bkpinfo->postnuke_tarball[0] = '\0';
 	bkpinfo->kernel_path[0] = '\0';
 	bkpinfo->nfs_mount[0] = '\0';
 	bkpinfo->nfs_remote_dir[0] = '\0';
-	bkpinfo->postnuke_tarball[0] = '\0';
 	bkpinfo->wipe_media_first = FALSE;
-	bkpinfo->differential = 0;
-	bkpinfo->please_dont_eject = FALSE;
+	bkpinfo->differential = FALSE;
 	bkpinfo->cdrw_speed = 0;
-	bkpinfo->manual_cd_tray = FALSE;
-	bkpinfo->nonbootable_backup = FALSE;
-	bkpinfo->make_cd_use_lilo = FALSE;
-	bkpinfo->use_obdr = FALSE;
-	bkpinfo->restore_mode = interactive;
+// patch by Herman Kuster  
+	bkpinfo->differential = 0;
+// patch end
+	bkpinfo->compression_level = 3;
 }
 
 
@@ -925,7 +1036,7 @@ long free_space_on_given_partition(char *partition)
 
 	assert_string_is_neither_NULL_nor_zerolength(partition);
 
-	sprintf(command, "df -m -P %s 1> /dev/null 2> /dev/null", partition);
+	sprintf(command, "df -m -P %s &> /dev/null", partition);
 	if (system(command)) {
 		return (-1);
 	}							// partition does not exist
@@ -948,6 +1059,7 @@ long free_space_on_given_partition(char *partition)
  * - check kernel for ramdisk support
  * - make sure afio, cdrecord, mkisofs, bzip2, awk, md5sum, strings, mindi, and buffer exist
  * - make sure CD-ROM is unmounted
+ * - make sure /etc/modules.conf exists
  * - make sure user's mountlist is OK by running <tt>mindi --makemountlist</tt>
  *
  * @return number of problems with the user's setup (0 for success)
@@ -961,12 +1073,14 @@ int some_basic_system_sanity_checks()
 
 	/*@ int's *************** */
 	int retval = 0;
+	long Lres;
+
 
 	mvaddstr_and_log_it(g_currentY, 0,
 						"Checking sanity of your Linux distribution");
 #ifndef __FreeBSD__
-	if (system("which mkfs.vfat 2> /dev/null 1> /dev/null")
-		&& !system("which mkfs.msdos 2> /dev/null 1> /dev/null")) {
+	if (system("which mkfs.vfat &> /dev/null")
+		&& !system("which mkfs.msdos &> /dev/null")) {
 		log_it
 			("OK, you've got mkfs.msdos but not mkfs.vfat; time for the fairy to wave her magic wand...");
 		run_program_and_log_output
@@ -985,6 +1099,14 @@ int some_basic_system_sanity_checks()
 	}
 #endif
 
+	Lres = free_space_on_given_partition(MINDI_CACHE);
+	log_it("Free space on partition of %s = %ld MB", MINDI_CACHE, Lres);
+
+	if (Lres < 50) {
+		sprintf(tmp, "The partition of %s has <50MB free. Please free up space or enlarge the partition or make %s a symbolic link.", MINDI_CACHE, MINDI_CACHE); 
+		fatal_error(tmp);
+	}
+
 	if (system("which " MKE2FS_OR_NEWFS " > /dev/null 2> /dev/null")) {
 		retval++;
 		log_to_screen
@@ -1020,9 +1142,20 @@ int some_basic_system_sanity_checks()
 	retval += whine_if_not_found("buffer");
 
 	// abort if Windows partition but no ms-sys and parted
-	if (!run_program_and_log_output("mount | grep -Ew 'vfat|fat|dos' | grep -vE \"/dev/fd|nexdisk\"", 0)) {
+	if (!run_program_and_log_output
+		("mount | grep -w vfat | grep -vE \"/dev/fd|nexdisk\"", 0)
+		||
+		!run_program_and_log_output
+		("mount | grep -w dos | grep -vE \"/dev/fd|nexdisk\"", 0)) {
 		log_to_screen("I think you have a Windows 9x partition.");
 		retval += whine_if_not_found("parted");
+#ifndef __IA64__
+		/* IA64 always has one vfat partition for EFI even without Windows */
+		// retval += 
+		if (!find_home_of_exe("ms-sys")) {
+			log_to_screen("Please install ms-sys just in case.");
+		}
+#endif
 	}
 
 	if (!find_home_of_exe("cmp")) {
@@ -1058,6 +1191,26 @@ int some_basic_system_sanity_checks()
 				("Your CD-ROM drive is mounted. Please unmount it.");
 		}
 	}
+#ifndef __FreeBSD__
+	if (!does_file_exist("/etc/modules.conf")) {
+		if (does_file_exist("/etc/conf.modules")) {
+			log_it("Linking /etc/modules.conf to /etc/conf.modules");
+			run_program_and_log_output
+				("ln -sf /etc/conf.modules /etc/modules.conf", 5);
+		} else if (does_file_exist("/etc/modprobe.d")) {
+			log_it
+				("Directory /etc/modprobe.d found. mindi will use its contents.");
+		} else if (does_file_exist("/etc/modprobe.conf")) {
+			log_it("Linking /etc/modules.conf to /etc/modprobe.conf");
+			run_program_and_log_output
+				("ln -sf /etc/modprobe.conf /etc/modules.conf", 5);
+		} else {
+			retval++;
+			log_to_screen
+				("Please find out what happened to /etc/modules.conf");
+		}
+	}
+#endif
 
 	run_program_and_log_output("cat /etc/fstab", 5);
 #ifdef __FreeBSD__
@@ -1073,10 +1226,10 @@ int some_basic_system_sanity_checks()
 		log_to_screen("Please uninstall and reinstall them both.");
 		fatal_error("Please reinstall Mondo and Mindi.");
 	}
-	sprintf(tmp, "mindi --makemountlist %s/mountlist.txt.test", bkpinfo->tmpdir);
-	if (run_program_and_log_output(tmp, 5)) {
-		sprintf(tmp, "mindi --makemountlist %s/mountlist.txt.test failed for some reason.", bkpinfo->tmpdir);
-		log_to_screen(tmp);
+	if (run_program_and_log_output
+		("mindi --makemountlist /tmp/mountlist.txt.test", 5)) {
+		log_to_screen
+			("Mindi --makemountlist /tmp/mountlist.txt.test failed for some reason.");
 		log_to_screen
 			("Please run that command by hand and examine /var/log/mindi.log");
 		log_to_screen
@@ -1260,36 +1413,32 @@ void mount_boot_if_necessary()
 	log_msg(4, "tmp = '%s'", tmp);
 	if (tmp[0]) {
 		log_it("/boot is at %s according to /etc/fstab", tmp);
-		strcpy(command, "mount | grep -Ew '/boot'");
-		strcpy(tmp, call_program_and_get_last_line_of_output(command));
-		if (!strcmp(tmp,"")) {
-			if ((strstr(tmp, "LABEL=") || strstr(tmp,"UUID="))) {
-				if (!run_program_and_log_output("mount /boot", 5)) {
-					strcpy(g_boot_mountpt, "/boot");
-					log_msg(1, "Mounted /boot");
-				} else {
-					log_it("...ignored cos it's a label or uuid :-)");
-				}
+		if ((strstr(tmp, "LABEL=") || strstr(tmp,"UUID="))) {
+			if (!run_program_and_log_output("mount /boot", 5)) {
+				strcpy(g_boot_mountpt, "/boot");
+				log_msg(1, "Mounted /boot");
 			} else {
-				sprintf(command, "mount | grep -E '^%s'", tmp);
-				log_msg(3, "command = %s", command);
-				if (run_program_and_log_output(command, 5)) {
-					strcpy(g_boot_mountpt, tmp);
-					sprintf(tmp,
-							"%s (your /boot partition) is not mounted. I'll mount it before backing up",
-							g_boot_mountpt);
-					log_it(tmp);
-					sprintf(tmp, "mount %s", g_boot_mountpt);
-					if (run_program_and_log_output(tmp, 5)) {
-						g_boot_mountpt[0] = '\0';
-						log_msg(1, "Plan B");
-						if (!run_program_and_log_output("mount /boot", 5)) {
-							strcpy(g_boot_mountpt, "/boot");
-							log_msg(1, "Plan B worked");
-						} else {
-							log_msg(1,
+				log_it("...ignored cos it's a label or uuid :-)");
+			}
+		} else {
+			sprintf(command, "mount | grep -E '^%s'", tmp);
+			log_msg(3, "command = %s", command);
+			if (run_program_and_log_output(command, 5)) {
+				strcpy(g_boot_mountpt, tmp);
+				sprintf(tmp,
+						"%s (your /boot partition) is not mounted. I'll mount it before backing up",
+						g_boot_mountpt);
+				log_it(tmp);
+				sprintf(tmp, "mount %s", g_boot_mountpt);
+				if (run_program_and_log_output(tmp, 5)) {
+					g_boot_mountpt[0] = '\0';
+					log_msg(1, "Plan B");
+					if (!run_program_and_log_output("mount /boot", 5)) {
+						strcpy(g_boot_mountpt, "/boot");
+						log_msg(1, "Plan B worked");
+					} else {
+						log_msg(1,
 								"Plan B failed. Unable to mount /boot for backup purposes. This probably means /boot is mounted already, or doesn't have its own partition.");
-						}
 					}
 				}
 			}
@@ -1344,7 +1493,9 @@ int write_cfg_var(char *config_file, char *label, char *value)
 		log_to_screen(tmp);
 		return (1);
 	}
-	sprintf(tempfile, "%s/mojo-jojo.blah", bkpinfo->tmpdir);
+	strcpy(tempfile,
+		   call_program_and_get_last_line_of_output
+		   ("mktemp -q /tmp/mojo-jojo.blah.XXXXXX"));
 	if (does_file_exist(config_file)) {
 		sprintf(command, "grep -vE '^%s .*$' %s > %s",
 				label, config_file, tempfile);
@@ -1385,7 +1536,7 @@ void standard_log_debug_msg(int debug_level, const char *szFile,
 		va_start(args, fmt);
 		if (!(fout = fopen(MONDO_LOGFILE, "a"))) {
 			return;
-		}		// fatal_error("Failed to openout to logfile - sheesh..."); }
+		}						// fatal_error("Failed to openout to logfile - sheesh..."); }
 
 		// add tabs to distinguish log levels
 		if (debug_level > 0) {
@@ -1436,19 +1587,19 @@ void (*log_debug_msg) (int, const char *, const char *, int, const char *,
 void do_libmondo_global_strings_thing(int mal)
 {
 	if (mal) {
+		iamhere("Malloc'ing globals");
 		malloc_string(g_boot_mountpt);
 		malloc_string(g_mondo_home);
-		/*
 		malloc_string(g_tmpfs_mountpt);
-		*/
+		malloc_string(g_erase_tmpdir_and_scratchdir);
 		malloc_string(g_serial_string);
 		malloc_string(g_magicdev_command);
 	} else {
+		iamhere("Freeing globals");
 		paranoid_free(g_boot_mountpt);
 		paranoid_free(g_mondo_home);
-		/*
 		paranoid_free(g_tmpfs_mountpt);
-		*/
+		paranoid_free(g_erase_tmpdir_and_scratchdir);
 		paranoid_free(g_serial_string);
 		paranoid_free(g_magicdev_command);
 	}
@@ -1458,6 +1609,7 @@ void do_libmondo_global_strings_thing(int mal)
 	   &g_boot_mountpt,
 	   &g_mondo_home,
 	   &g_tmpfs_mountpt,
+	   &g_erase_tmpdir_and_scratchdir,
 	   &g_serial_string,
 	   &g_magicdev_command,
 	   NULL};
