@@ -4,7 +4,7 @@
     begin                : Fri Apr 19 2002
     copyright            : (C) 2002 by Stan Benoit
     email                : troff@nakedsoul.org
-    cvsid                : $Id: mondostructures.h 1967 2008-05-29 15:40:05Z bruno $
+    cvsid                : $Id: mondostructures.h 1295 2007-04-11 18:59:49Z bruno $
  ***************************************************************************/
 
 /***************************************************************************
@@ -58,10 +58,14 @@ struct mountlist_line {
 	long long size;
 
   /**
-   * For ext2 and ext3, this is the filesystem label or uuid (if there is one). If not, this should be "".
+   * For ext2 and ext3, this is the filesystem label (if there is one). If not, this should be "".
    */
 	char label[256];
 
+	/**
+	 * This is the filesystem UUID (if there is one). If not, this should be "".
+	 */
+	char uuid[64];
 };
 
 /**
@@ -150,12 +154,12 @@ struct s_disk {
    * Index number of this entry in the whole disklist.
    */
 	int index;
-
+	
   /**
    * Type of disk.
    */
 	char type;  // ' ' = data (default), S = spare, F = faulty
-
+	
 };
 
 /**
@@ -184,7 +188,6 @@ typedef enum { none = 0,		///< No type has been set yet.
 	cdstream,					///< Back up to recordable CDs but treat them like a tape streamer.
 	nfs,						///< Back up to an NFS mount on the local subnet.
 	tape,						///< Back up to tapes.
-	usb,						///< Back up to USB devices.
 	udev						///< Back up to another unsupported device; just send a stream of bytes.
 } t_bkptype;
 
@@ -196,18 +199,6 @@ typedef enum { other,			///< Some other kind of file.
 	biggieslice					///< A slice of a biggiefile, optionally compressed.
 } t_archtype;
 
-/**
- * A type of file in the catalog of recent archives.
- */
-typedef enum {
-	nuke = 0,					/// Nuke mode
-	interactive,				/// Interactive mode
-	compare,					/// Compare mode
-	mbr,						/// MBR mode
-	isoonly,					/// ISO mode
-	isonuke,					/// ISO+Nuke mode
-} t_restore_mode;
-
 
 #ifdef __FreeBSD__
 
@@ -260,7 +251,7 @@ struct raid_device_record {
 	   * The chunk size of this RAID device.
 	   */
 	int chunk_size;
-
+	
 	  /**
 	   * The parity algorithm of this RAID device. (RAID5 only)
 	   */
@@ -336,7 +327,7 @@ struct s_bkpinfo {
   /**
    * The device we're backing up to.
    * If backup_media_type is @b cdr, @b cdrw, or @b cdstream, this should be the SCSI node (e.g. 0,1,0).
-   * If backup_media_type is @b dvd, @b tape, @b usb or @b udev, this should be a /dev entry.
+   * If backup_media_type is @b dvd, @b tape, or @b udev, this should be a /dev entry.
    * If backup_media_type is anything else, this should be blank.
    */
 	char media_device[MAX_STR_LEN / 4];
@@ -582,13 +573,13 @@ struct s_bkpinfo {
    */
 	bool wipe_media_first;
 
-// patch by Herman Kuster
+// patch by Herman Kuster  
   /**
    * The differential level of this backup. Currently only 0 (full backup) and 1
    * (files changed since last full backup) are supported.
    */
 	int differential;
-// end patch
+// end patch  
 
   /**
    * If TRUE, then don't eject media when backing up or restoring.
@@ -617,16 +608,6 @@ struct s_bkpinfo {
    * If TRUE, make the bootable CD use LILO/ELILO. If FALSE, use isolinux (the default).
    */
 	bool make_cd_use_lilo;
-
-  /**
-   * If TRUE, make the the tape bootable. If FALSE, normal tape, the default
-   */
-	bool use_obdr;
-
-  /**
-   * Nature of the restore
-   */
-	t_restore_mode restore_mode;
 };
 
 
