@@ -1,5 +1,5 @@
 /* newt-specific.c
-   $Id: newt-specific.c 1316 2007-04-16 14:50:28Z bruno $
+   $Id: newt-specific.c 1463 2007-05-29 12:48:16Z bruno $
 
   subroutines which do display-type things
   and use the newt library to do them
@@ -123,7 +123,7 @@ extern "C" {
 extern char *MONDO_LOGFILE;
 
 /*@unused@*/
-//static char cvsid[] = "$Id: newt-specific.c 1316 2007-04-16 14:50:28Z bruno $";
+//static char cvsid[] = "$Id: newt-specific.c 1463 2007-05-29 12:48:16Z bruno $";
 
 	extern pid_t g_mastermind_pid;
 	extern char *g_tmpfs_mountpt;
@@ -1448,7 +1448,7 @@ char *tmp = NULL;
 		newtCenteredWindow(34, 13, "How much compression?");
 		b1 = newtButton(4, 1, "Maximum");
 		b2 = newtButton(18, 1, "Average");
-		b3 = newtButton(4, 5, "Minumum");
+		b3 = newtButton(4, 5, "Minimum");
 		b4 = newtButton(18, 5, " None  ");
 		b5 = newtButton(4, 9, "         Exit        ");
 		myForm = newtForm(NULL, NULL, 0);
