@@ -7,7 +7,7 @@ copyright : (C) 2002 Mondo  Hugo Rabson
 email     : Hugo Rabson <hugorabson@msn.com>
 edited by : by Stan Benoit 4/2002
 email     : troff@nakedsoul.org
-cvsid     : $Id: mondo-prep.c 1320 2007-04-16 17:24:58Z bruno $
+cvsid     : $Id: mondo-prep.c 1497 2007-06-08 23:33:26Z bruno $
 ***************************************************************************/
 
 /***************************************************************************
@@ -180,7 +180,7 @@ cvsid     : $Id: mondo-prep.c 1320 2007-04-16 17:24:58Z bruno $
 #define ARCHIVES_PATH MNT_CDROM"/archives"
 #define MONDO_WAS_HERE "MONDOWOZEREMONDOWOZEREMONDOWOZEREhahahaMOJOJOJO"
 
-//static char cvsid[] = "$Id: mondo-prep.c 1320 2007-04-16 17:24:58Z bruno $";
+//static char cvsid[] = "$Id: mondo-prep.c 1497 2007-06-08 23:33:26Z bruno $";
 
 extern char *g_mountlist_fname;
 extern long g_current_progress, g_maximum_progress;
@@ -2211,6 +2211,8 @@ int set_partition_type(FILE * pout_to_fdisk, const char *drive, int partno,
 		strcpy(partcode, "83");
 	} else if (strcmp(format, "minix") == 0) {
 		strcpy(partcode, "81");
+	} else if (strcmp(format, "vmfs") == 0) {
+		strcpy(partcode, "fb");
 	} else if (strcmp(format, "raid") == 0) {
 		strcpy(partcode, "fd");
 	} else if ((strcmp(format, "ufs") == 0)
@@ -2531,6 +2533,8 @@ int which_format_command_do_i_need(char *format, char *program)
 		strcpy(program, "mkfs -t ext2 -F -j -q");
 	} else if (strcmp(format, "minix") == 0) {
 		strcpy(program, "mkfs.minix");
+	} else if (strcmp(format, "vmfs") == 0) {
+		strcpy(program, "mkfs -t vmfs");
 #endif
 	} else if (strcmp(format, "ext2") == 0) {
 		strcpy(program, "mke2fs -F -q");
