@@ -4,7 +4,7 @@
     begin                : Fri Apr 25 2003
     copyright            : (C) 2000 by Hugo Rabson
     email                : Hugo Rabson <hugorabson@msn.com>
-    cvsid                : $Id: mondo-rstr-compare.c 1930 2008-04-22 12:05:49Z bruno $
+    cvsid                : $Id: mondo-rstr-compare.c 1321 2007-04-16 19:11:19Z bruno $
 ***************************************************************************/
 
 /***************************************************************************
@@ -55,7 +55,7 @@
 
 
 #include <pthread.h>
-#include "my-stuff.h"
+#include "../common/my-stuff.h"
 #include "../common/mondostructures.h"
 #include "../common/libmondo.h"
 //#include "../../config.h"
@@ -66,12 +66,7 @@
 
 extern char *MONDO_LOGFILE;
 
-/* Reference to global bkpinfo */
-extern struct s_bkpinfo *bkpinfo;
-
-extern char *g_mountlist_fname;
-
-//static char cvsid[] = "$Id: mondo-rstr-compare.c 1930 2008-04-22 12:05:49Z bruno $";
+//static char cvsid[] = "$Id: mondo-rstr-compare.c 1321 2007-04-16 19:11:19Z bruno $";
 
 void popup_changelist_from_file(char *);
 
@@ -86,7 +81,7 @@ void popup_changelist_from_file(char *);
  * @param bigfileno The biggiefile number (starting from 0) to compare.
  * @note This function uses an MD5 checksum.
  */
-int compare_a_biggiefile(long bigfileno)
+int compare_a_biggiefile(struct s_bkpinfo *bkpinfo, long bigfileno)
 {
 
 	FILE *fin;
@@ -131,7 +126,7 @@ int compare_a_biggiefile(long bigfileno)
 
 	if (!does_file_exist(slice_fname(bigfileno, 0, ARCHIVES_PATH, ""))) {
 		if (does_file_exist(MNT_CDROM "/archives/NOT-THE-LAST")) {
-			insist_on_this_cd_number((++g_current_media_number));
+			insist_on_this_cd_number(bkpinfo, (++g_current_media_number));
 		} else {
 			sprintf(tmp_ptr,
 					"No CD's left. No biggiefiles left. No prob, Bob.");
@@ -206,7 +201,7 @@ int compare_a_biggiefile(long bigfileno)
 	}
 	log_msg(1, tmp_ptr);
 	if (retval) {
-		if (!(fout = fopen(MONDO_CACHE"/changed.txt", "a"))) {
+		if (!(fout = fopen("/tmp/changed.txt", "a"))) {
 			fatal_error("Cannot openout changed.txt");
 		}
 		fprintf(fout, "%s\n", bigfile_fname_ptr);
@@ -234,15 +229,17 @@ int compare_a_biggiefile(long bigfileno)
 
 /**
  * Compare all biggiefiles in the backup.
+ * @param bkpinfo The backup information structure. Used only in compare_a_biggiefile().
  * @return 0 for success, nonzero for failure.
  */
-int compare_all_biggiefiles()
+int compare_all_biggiefiles(struct s_bkpinfo *bkpinfo)
 {
 	int retval = 0;
 	int res;
 	long noof_biggiefiles, bigfileno = 0;
 	char tmp[MAX_STR_LEN];
 
+	assert(bkpinfo != NULL);
 	log_msg(1, "Comparing biggiefiles");
 
 	if (length_of_file(BIGGIELIST) < 6) {
@@ -265,7 +262,7 @@ int compare_all_biggiefiles()
 		sprintf(tmp, "Comparing big file #%ld", bigfileno + 1);
 		log_msg(1, tmp);
 		update_progress_form(tmp);
-		res = compare_a_biggiefile(bigfileno);
+		res = compare_a_biggiefile(bkpinfo, bigfileno);
 		retval += res;
 		g_current_progress++;
 	}
@@ -379,11 +376,10 @@ int compare_a_tarball(char *tarball_fname, int current_tarball_number)
 	if (res) {
 		log_OS_error(command);
 		sprintf(tmp, "Warning - afio returned error = %d", res);
-		log_msg(2, tmp);
 	}
 	if (length_of_file(logfile) > 5) {
 		sprintf(command,
-				"sed s/': \\\"'/\\|/ %s | sed s/'\\\": '/\\|/ | cut -d'|' -f2 | sort -u | grep -vE \"^dev/.*\" >> "MONDO_CACHE"/changed.txt",
+				"sed s/': \\\"'/\\|/ %s | sed s/'\\\": '/\\|/ | cut -d'|' -f2 | sort -u | grep -vE \"^dev/.*\" >> /tmp/changed.txt",
 				logfile);
 		system(command);
 		archiver_errors = count_lines_in_file(logfile);
@@ -404,8 +400,8 @@ int compare_a_tarball(char *tarball_fname, int current_tarball_number)
 	paranoid_free(tmp);
 	paranoid_free(filelist_name);
 	paranoid_free(logfile);
-	paranoid_free(archiver_exe);
-	paranoid_free(compressor_exe);
+	malloc_string(archiver_exe);
+	malloc_string(compressor_exe);
 	return (retval);
 }
 
@@ -419,7 +415,7 @@ int compare_a_tarball(char *tarball_fname, int current_tarball_number)
  * @param bkpinfo The backup media structure. Passed to other functions.
  * @return 0 for success, nonzero for failure.
  */
-int compare_all_tarballs()
+int compare_all_tarballs(struct s_bkpinfo *bkpinfo)
 {
 	int retval = 0;
 	int res;
@@ -451,7 +447,7 @@ int compare_all_tarballs()
 	log_to_screen(progress_str);
 
 	for (;;) {
-		insist_on_this_cd_number(g_current_media_number);
+		insist_on_this_cd_number(bkpinfo, g_current_media_number);
 		update_progress_form(progress_str);
 		sprintf(tarball_fname,
 				MNT_CDROM "/archives/%d.afio.bz2", current_tarball_number);
@@ -460,10 +456,6 @@ int compare_all_tarballs()
 			sprintf(tarball_fname, MNT_CDROM "/archives/%d.afio.lzo",
 					current_tarball_number);
 		}
-		if (!does_file_exist(tarball_fname)) {
-			sprintf(tarball_fname, MNT_CDROM "/archives/%d.afio.gz",
-					current_tarball_number);
-		}
 		if (!does_file_exist(tarball_fname)) {
 			sprintf(tarball_fname, MNT_CDROM "/archives/%d.afio.",
 					current_tarball_number);
@@ -525,7 +517,7 @@ int compare_all_tarballs()
  * @param bkpinfo The backup information structure. Passed to other functions.
  * @return 0 for success, nonzero for failure.
  */
-int compare_to_CD()
+int compare_to_CD(struct s_bkpinfo *bkpinfo)
 {
   /** needs malloc *********/
 	char *tmp, *cwd, *new, *command;
@@ -543,19 +535,20 @@ int compare_to_CD()
 	getcwd(cwd, MAX_STR_LEN - 1);
 	chdir(bkpinfo->restore_path);
 	getcwd(new, MAX_STR_LEN - 1);
-	insist_on_this_cd_number(g_current_media_number);
-	unlink(MONDO_CACHE"/changed.txt");
+	sprintf(tmp, "new path is %s", new);
+	insist_on_this_cd_number(bkpinfo, g_current_media_number);
+	unlink("/tmp/changed.txt");
 
-	resA = compare_all_tarballs();
-	resB = compare_all_biggiefiles();
+	resA = compare_all_tarballs(bkpinfo);
+	resB = compare_all_biggiefiles(bkpinfo);
 	chdir(cwd);
-	noof_changed_files = count_lines_in_file(MONDO_CACHE"/changed.txt");
+	noof_changed_files = count_lines_in_file("/tmp/changed.txt");
 	if (noof_changed_files) {
 		sprintf(tmp, "%ld files do not match the backup            ",
 				noof_changed_files);
 		//      mvaddstr_and_log_it( g_currentY++, 0, tmp );
 		log_to_screen(tmp);
-		sprintf(command, "cat "MONDO_CACHE"/changed.txt >> %s", MONDO_LOGFILE);
+		sprintf(command, "cat /tmp/changed.txt >> %s", MONDO_LOGFILE);
 		paranoid_system(command);
 	} else {
 		sprintf(tmp, "All files match the backup                     ");
@@ -588,19 +581,15 @@ int compare_to_CD()
  * @return The number of errors/differences found.
  */
 int
-compare_mode(struct mountlist_itself *mountlist,
+compare_mode(struct s_bkpinfo *bkpinfo,
+			 struct mountlist_itself *mountlist,
 			 struct raidlist_itself *raidlist)
 {
 	int retval = 0;
-	int res = 0;
 	long q;
 	char *tmp;
-	char *new;
-	char *cwd;
 
 	malloc_string(tmp);
-	malloc_string(new);
-	malloc_string(cwd);
 
   /**************************************************************************
    * also deletes tmp/filelist.full & tmp/biggielist.txt _and_ tries to     *
@@ -610,34 +599,16 @@ compare_mode(struct mountlist_itself *mountlist,
 	assert(mountlist != NULL);
 	assert(raidlist != NULL);
 
-	while (get_cfg_file_from_archive()) {
+	while (get_cfg_file_from_archive(bkpinfo)) {
 		if (!ask_me_yes_or_no
 			("Failed to find config file/archives. Choose another source?"))
 		{
 			fatal_error("Unable to find config file/archives. Aborting.");
 		}
-		interactively_obtain_media_parameters_from_user(FALSE);
+		interactively_obtain_media_parameters_from_user(bkpinfo, FALSE);
 	}
 
-	read_cfg_file_into_bkpinfo(g_mondo_cfg_file);
-
-	/* edit_mountlist if wanted */
-	iamhere("About to edit mountlist");
-	if (g_text_mode) {
-		save_mountlist_to_disk(mountlist, g_mountlist_fname);
-		sprintf(tmp, "%s %s", find_my_editor(), g_mountlist_fname);
-		res = system(tmp);
-		load_mountlist(mountlist, g_mountlist_fname);
-	} else {
-		res = edit_mountlist(g_mountlist_fname, mountlist, raidlist);
-	}
-	iamhere("Finished editing mountlist");
-	if (res) {
-		paranoid_MR_finish(1);
-	}
-	save_mountlist_to_disk(mountlist, g_mountlist_fname);
-	save_raidlist_to_raidtab(raidlist, RAIDTAB_FNAME);
-
+	read_cfg_file_into_bkpinfo(g_mondo_cfg_file, bkpinfo);
 	g_current_media_number = 1;
 	mvaddstr_and_log_it(1, 30, "Comparing Automatically");
 	iamhere("Pre-MAD");
@@ -649,11 +620,11 @@ compare_mode(struct mountlist_itself *mountlist,
 	}
 	if (bkpinfo->backup_media_type == tape
 		|| bkpinfo->backup_media_type == udev) {
-		retval += compare_to_tape();
+		retval += compare_to_tape(bkpinfo);
 	} else if (bkpinfo->backup_media_type == cdstream) {
-		retval += compare_to_cdstream();
+		retval += compare_to_cdstream(bkpinfo);
 	} else {
-		retval += compare_to_CD();
+		retval += compare_to_CD(bkpinfo);
 	}
 	if (retval) {
 		mvaddstr_and_log_it(g_currentY++,
@@ -661,17 +632,19 @@ compare_mode(struct mountlist_itself *mountlist,
 							"Warning - differences found during the compare phase");
 	}
 
-	if (count_lines_in_file(MONDO_CACHE"/changed.txt") > 0) {
+	retval += unmount_all_devices(mountlist);
+
+	if (count_lines_in_file("/tmp/changed.txt") > 0) {
 		mvaddstr_and_log_it(g_currentY++, 0,
 							"Differences found while files were being compared.");
-		streamline_changes_file(MONDO_CACHE"/changed.files", MONDO_CACHE"/changed.txt");
-		if (count_lines_in_file(MONDO_CACHE"/changed.files") <= 0) {
+		streamline_changes_file("/tmp/changed.files", "/tmp/changed.txt");
+		if (count_lines_in_file("/tmp/changed.files") <= 0) {
 			mvaddstr_and_log_it(g_currentY++, 0,
 								"...but they were logfiles and temporary files. Your archives are fine.");
 			log_to_screen
 				("The differences were logfiles and temporary files. Your archives are fine.");
 		} else {
-			q = count_lines_in_file(MONDO_CACHE"/changed.files");
+			q = count_lines_in_file("/tmp/changed.files");
 			sprintf(tmp, "%ld significant difference%s found.", q,
 					(q != 1) ? "s" : "");
 			mvaddstr_and_log_it(g_currentY++, 0, tmp);
@@ -683,23 +656,15 @@ compare_mode(struct mountlist_itself *mountlist,
 			log_to_screen(tmp);
 
 			log_msg(2, "calling popup_changelist_from_file()");
-			getcwd(cwd, MAX_STR_LEN - 1);
-			chdir(bkpinfo->restore_path);
-			getcwd(new, MAX_STR_LEN - 1);
-			popup_changelist_from_file(MONDO_CACHE"/changed.files");
-			chdir(cwd);
+			popup_changelist_from_file("/tmp/changed.files");
 			log_msg(2, "Returning from popup_changelist_from_file()");
 		}
 	} else {
 		log_to_screen
 			("No significant differences were found. Your backup is perfect.");
 	}
-	retval += unmount_all_devices(mountlist);
-
 	kill_petris();
 	paranoid_free(tmp);
-	paranoid_free(new);
-	paranoid_free(cwd);
 	return (retval);
 }
 
@@ -715,7 +680,7 @@ compare_mode(struct mountlist_itself *mountlist,
  * - @c bkpinfo->restore_path
  * @return 0 for success, nonzero for failure.
  */
-int compare_to_cdstream()
+int compare_to_cdstream(struct s_bkpinfo *bkpinfo)
 {
 	int res;
 
@@ -741,14 +706,14 @@ int compare_to_cdstream()
 	} else {
 		find_cdrom_device(bkpinfo->media_device, FALSE);
 	}
-	res = verify_tape_backups();
+	res = verify_tape_backups(bkpinfo);
 	chdir(dir);
-	if (length_of_file(MONDO_CACHE"/changed.txt") > 2
-		&& length_of_file(MONDO_CACHE"/changed.files") > 2) {
+	if (length_of_file("/tmp/changed.txt") > 2
+		&& length_of_file("/tmp/changed.files") > 2) {
 		log_msg(0,
-				"Type 'less "MONDO_CACHE"/changed.files' to see which files don't match the archives");
+				"Type 'less /tmp/changed.files' to see which files don't match the archives");
 		log_msg(2, "Calling popup_changelist_from_file()");
-		popup_changelist_from_file(MONDO_CACHE"/changed.files");
+		popup_changelist_from_file("/tmp/changed.files");
 		log_msg(2, "Returned from popup_changelist_from_file()");
 	}
 
@@ -774,7 +739,7 @@ int compare_to_cdstream()
  *                                                                        *
  * returns: int                                                           *
  **************************************************************************/
-int compare_to_tape()
+int compare_to_tape(struct s_bkpinfo *bkpinfo)
 {
 	int res;
 	char *dir, *command;
@@ -790,7 +755,7 @@ int compare_to_tape()
 	run_program_and_log_output(command, FALSE);
 	mvaddstr_and_log_it(g_currentY,
 						0, "Verifying archives against filesystem");
-	res = verify_tape_backups();
+	res = verify_tape_backups(bkpinfo);
 	chdir(dir);
 	if (res) {
 		mvaddstr_and_log_it(g_currentY++, 74, "Failed.");
