@@ -845,34 +845,34 @@ malloc_string(mountpoint);
 malloc_string(additional_parameters);
 
 if (!strcmp(mpt, "/1")) {
-strcpy(mountpoint, "/");
-log_msg(3, "Mommm! SME is being a dildo!");
+	strcpy(mountpoint, "/");
+	log_msg(3, "Mommm! SME is being a dildo!");
 } else {
-strcpy(mountpoint, mpt);
+	strcpy(mountpoint, mpt);
 }
 
 if (!strcmp(mountpoint, "lvm")) {
-return (0);
+	return (0);
 }
 if (!strcmp(mountpoint, "image")) {
-return (0);
+	return (0);
 }
 sprintf(tmp, "Mounting device %s   ", device);
 log_msg(1, tmp);
 if (writeable) {
-strcpy(additional_parameters, "-o rw");
+	strcpy(additional_parameters, "-o rw");
 } else {
-strcpy(additional_parameters, "-o ro");
+	strcpy(additional_parameters, "-o ro");
 }
 if (find_home_of_exe("setfattr")) {
-strcat(additional_parameters, ",user_xattr");
+	strcat(additional_parameters, ",user_xattr");
 }
 if (find_home_of_exe("setfacl")) {
-strcat(additional_parameters, ",acl");
+	strcat(additional_parameters, ",acl");
 }
 
 if (!strcmp(mountpoint, "swap")) {
-sprintf(command, "swapon %s", device);
+	sprintf(command, "swapon %s", device);
 } else {
 if (!strcmp(mountpoint, "/")) {
 	strcpy(mountdir, MNT_RESTORING);
@@ -887,35 +887,35 @@ log_msg(2, "command='%s'", command);
 }
 res = run_program_and_log_output(command, TRUE);
 if (res && (strstr(command, "xattr") || strstr(command, "acl"))) {
-log_msg(1, "Re-trying without the fancy extra parameters");
-sprintf(command, "mount -t %s %s %s 2>> %s", format, device,
+	log_msg(1, "Re-trying without the fancy extra parameters");
+	sprintf(command, "mount -t %s %s %s 2>> %s", format, device,
 		mountdir, MONDO_LOGFILE);
-res = run_program_and_log_output(command, TRUE);
+	res = run_program_and_log_output(command, TRUE);
 }
 if (res) {
-log_msg(1, "Unable to mount device %s (type %s) at %s", device,
+	log_msg(1, "Unable to mount device %s (type %s) at %s", device,
 		format, mountdir);
-log_msg(1, "command was '%s'", command);
-if (!strcmp(mountpoint, "swap")) {
-	log_to_screen(tmp);
-} else {
-	log_msg(2, "Retrying w/o the '-t' switch");
-	sprintf(command, "mount %s %s 2>> %s", device, mountdir,
-			MONDO_LOGFILE);
-	log_msg(2, "2nd command = '%s'", command);
-	res = run_program_and_log_output(command, TRUE);
-	if (res == 0) {
-		log_msg(1,
-				"That's OK. I called mount w/o a filesystem type and it worked fine in the end.");
-	} else {
+	log_msg(1, "command was '%s'", command);
+	if (!strcmp(mountpoint, "swap")) {
 		log_to_screen(tmp);
+	} else {
+		log_msg(2, "Retrying w/o the '-t' switch");
+		sprintf(command, "mount %s %s 2>> %s", device, mountdir,
+			MONDO_LOGFILE);
+		log_msg(2, "2nd command = '%s'", command);
+		res = run_program_and_log_output(command, TRUE);
+		if (res == 0) {
+			log_msg(1,
+				"That's OK. I called mount w/o a filesystem type and it worked fine in the end.");
+		} else {
+			log_to_screen(tmp);
+		}
 	}
 }
-}
 if (res && !strcmp(mountpoint, "swap")) {
-log_msg(2, "That's ok. It's just a swap partition.");
-log_msg(2, "Non-fatal error. Returning 0.");
-res = 0;
+	log_msg(2, "That's ok. It's just a swap partition.");
+	log_msg(2, "Non-fatal error. Returning 0.");
+	res = 0;
 }
 
 paranoid_free(tmp);
@@ -1699,9 +1699,9 @@ int run_grub(bool offer_to_run_stabgrub, char *bd)
 			if (!g_text_mode) {
 				newtSuspend();
 			}
-			sprintf(tmp, "%s " MNT_RESTORING "/etc/fstab", editor);
+			sprintf(tmp, "chroot %s %s /etc/fstab", MNT_RESTORING, editor);
 			paranoid_system(tmp);
-			sprintf(tmp, "%s " MNT_RESTORING "/etc/grub.conf", editor);
+			sprintf(tmp, "chroot %s %s /etc/grub.conf", MNT_RESTORING, editor);
 			paranoid_system(tmp);
 			if (!g_text_mode) {
 				newtResume();
@@ -2410,16 +2410,22 @@ int get_cfg_file_from_archive(struct s_bkpinfo *bkpinfo)
 	sprintf(tmp, "mkdir -p %s/tmp", bkpinfo->tmpdir);
 	run_program_and_log_output(tmp, FALSE);
 
-	sprintf(command, "mount /dev/fd0u1722 %s", mountpt);
-	sprintf(tmp,
+	/* Is there a floppy drive detected */
+	sprintf(tmp, "%s", call_program_and_get_last_line_of_output("dmesg | grep -i floppy"));
+	if (strcmp(tmp, "")) {
+		sprintf(command, "mount /dev/fd0u1722 %s", mountpt);
+		sprintf(tmp,
 			"(sleep 15; kill `ps | grep \"%s\" | cut -d' ' -f1` 2> /dev/null) &",
 			command);
-	log_msg(1, "tmp = '%s'", tmp);
-	system(tmp);
-	res = run_program_and_log_output(command, FALSE);
-	if (res) {
-		sprintf(command, "mount /dev/fd0H1440 %s", mountpt);
+		log_msg(1, "tmp = '%s'", tmp);
+		system(tmp);
 		res = run_program_and_log_output(command, FALSE);
+		if (res) {
+			sprintf(command, "mount /dev/fd0H1440 %s", mountpt);
+			res = run_program_and_log_output(command, FALSE);
+		}
+	} else {
+		res = 1;
 	}
 	if (res) {
 		try_plan_B = TRUE;
@@ -2427,7 +2433,7 @@ int get_cfg_file_from_archive(struct s_bkpinfo *bkpinfo)
 		try_plan_B = TRUE;
 		log_msg(2,
 				"Mounted floppy OK but I don't trust it because the archives might contain more up-to-date config file than the floppy does.");
-// NB: If busybox does not support 'mount -o loop' then Plan A WILL NOT WORK.
+		// NB: If busybox does not support 'mount -o loop' then Plan A WILL NOT WORK.
 		log_msg(2, "Processing floppy (plan A?)");
 		sprintf(ramdisk_fname, "%s/mindi.rdz", mountpt);
 		if (!does_file_exist(ramdisk_fname)) {
@@ -2498,6 +2504,7 @@ int get_cfg_file_from_archive(struct s_bkpinfo *bkpinfo)
 				return (1);
 			}
 		} else {
+			/* That boot imae doesn't always exist where the following method always works 
 			log_msg(2,
 					"gcffa --- looking at mounted CD for mindi-boot.2880.img");
 			sprintf(command,
@@ -2505,15 +2512,18 @@ int get_cfg_file_from_archive(struct s_bkpinfo *bkpinfo)
 					"/images/mindi-boot.2880.img -o loop %s", mountpt);
 			sprintf(mounted_cfgf_path, "%s/%s", mountpt, cfg_file);
 			if (!does_file_exist(mounted_cfgf_path)) {
+			*/
 				log_msg(2,
-						"gcffa --- Plan C, a.k.a. untarring some file from all.tar.gz");
+						"gcffa --- Plan B, a.k.a. untarring some file from all.tar.gz");
 				sprintf(command, "tar -zxvf " MNT_CDROM "/images/all.tar.gz %s %s %s %s %s", MOUNTLIST_FNAME_STUB, MONDO_CFG_FILE_STUB, BIGGIELIST_TXT_STUB, FILELIST_FULL_STUB, "tmp/i-want-my-lvm");	// add -b TAPE_BLOCK_SIZE if you _really_ think it's necessary
 				run_program_and_log_output(command, TRUE);
 				if (!does_file_exist(MONDO_CFG_FILE_STUB)) {
 					fatal_error
 						("Please reinsert the disk/CD and try again.");
 				}
+					/*
 			}
+				*/
 		}
 	}
 	if (does_file_exist(MONDO_CFG_FILE_STUB)) {
