@@ -7,8 +7,7 @@
 /**
  * Compatibility #define to ease the transition to logfile-in-a-variable.
  */
-char *MONDO_LOGFILE = "/var/log/mondorestore.log";
-char *MONDO_OPTIONS = "E:GI:J:K:QRT:UVZ:b:d:ef:gimn:op:tux:z";
+char *MONDO_LOGFILE = "/tmp/mondorestore.log";
 
 /* Busybox ps has no option and PID in first pos */
 char *ps_options = "";
